# 🏜️ DESERTAS CODE OF CONDUCT

## Contributor Covenant Code of Conduct v2.1

### Our Pledge

We as members, contributors, and leaders pledge to make participation in our
community a harassment-free experience for everyone.

---

### Our Standards

Examples of behavior that contributes to a positive environment:

* 🧠 **Demonstrating empathy and kindness** toward other people
* 🏜️ **Respecting different opinions, viewpoints, and experiences**
* 🤝 **Giving and gracefully accepting constructive feedback**
* 🌍 **Prioritizing ethical research practices**

Examples of unacceptable behavior:

* ❌ The use of sexualized language or imagery
* ❌ Trolling, insulting or derogatory comments
* ❌ Public or private harassment
* ❌ Publishing others' private information without permission
* ❌ Disrespecting Indigenous knowledge protocols

---

### Special Considerations for DESERTAS Research

As this project involves collaboration with Indigenous communities:

* 🔐 **Respecting Indigenous data sovereignty**
* 📋 **Obtaining FPIC** before using Indigenous knowledge
* 🏷️ **Proper attribution** of Indigenous knowledge contributions

---

### Enforcement

Instances of abusive behavior may be reported to:

**Email:** conduct@desertas.org  
**Principal Investigator:** gitdeeper@gmail.com

---

### Contact

For Code of Conduct issues: conduct@desertas.org  
For Indigenous knowledge protocols: indigenous@desertas.org  
For general inquiries: gitdeeper@gmail.com

---

**DESERTAS** 🏜️ *The Desert Breathes*

*Last Updated: March 2026*
